@@ -43,7 +43,7 @@ sub logf($);
 my $ifconfig_llp="/etc/ifconfig_llp.txt";
 my $log="/var/log/llp.log";
 #
-my $version="0.8";
+my $version="1.1";
 getopts("hd")||die "ERROR: No such option. -h for help.\n";
 help() if ($opt_h);
 $ARGV[0] || help();
@@ -55,9 +55,11 @@ $SIG{INT} = \&catch_sig;
 $SIG{HUP} = 'IGNORE';
 $SIG{TERM} = \&catch_sig;
 $SIG{QUIT} = \&catch_sig;
+$|=1;
 #
 my ($rin,$rout,$timeout,$nfound,$timeleft);
 my ($str);
+my $dbgprintstr='';
 (-w "$ifconfig_llp")||die "ERROR: file $ifconfig_llp not writeable for this process (pid $$ = $0)\n";
 # initialize the serial line:
 print `ttydevinit \"$dev\" 2>&1`;
@@ -75,19 +77,23 @@ lcdsend("b=1"); # do it twice to clear any garbage that might be on
 lcdsend("l=10"); # red off
 lcdsend("w=?"); # check for timeout
 lcdsend("w=2"); # autokick watchdog
+lcdsend("w=0"); # autokick watchdog
 lcdsend("c=n"); # normal cursor
 idletask();
 processqueue();
 while(1){
     vec($rin,fileno(LCD),1)=1;
 	($nfound,$timeleft) = select($rout=$rin, undef, undef, $timeout);
+    #$dbgprintstr.="DBG timeleft=$timeleft nfound=$nfound timeout=$timeout\n" if ($opt_d);
 	if ($nfound){
         # data is available
 		sysread LCD,$str,40; # there will never be more than 40 bytes
         check_for_button_press($str);
         logf("watchdog did timeout") if ($str=~/w:3/);
-		print "$str" if ($opt_d);
+		$dbgprintstr.="$str" if ($opt_d);
 	}
+    print $dbgprintstr;
+    $dbgprintstr='';
     processqueue();
 }
 #----------------------------------
@@ -277,12 +283,16 @@ sub processqueue(){
     if (@processqueue){
         $cmd=shift @processqueue;
         if ($cmd->{'cmd'} eq "sleepifidle"){
-            print "sleepifidle\n" if($opt_d); # dbg
+            $dbgprintstr.="sleepifidle\n" if($opt_d); # dbg
             return(0);
         }
         if ($cmd->{'cmd'} eq "lcd"){
             syswrite LCD,$cmd->{'val'}."\n";
-            print $cmd->{'val'}."\n" if($opt_d); # dbg
+            $dbgprintstr.=$cmd->{'val'}."\n" if($opt_d); # dbg
+            # with a usb to serial converter it can happen
+            # that the uC is not fast enough (or the usb does not
+	    # send the data fast enough):
+            select(undef, undef, undef, 0.05); # usleep 50 
         }
     }else{
         if ($state{'menutimeout'}==1){
